import java.util.*;
import java.io.*;

public class Certificate {

    private int noCars;                // number of cars
    private int noOpt;                 // number of options
    private int noClass;               // number of classes
    private int[] p;                   // number of cars with option i in a block
    private int[] q;                   // size of a block for option i
    private int[] demand;              // demand for class i, i.e. number of cars of class i
    private int[][] option;            // option[i][j] = 1 <-> class i requires option j
    private int[] optDemand;           // demand for an option
    private int[] posn;                // position, the class of car in this slot
    private int[][] posnOpt;           // actual options taken at given positions
	
    public Certificate(String fname1,String fname2) throws Exception {
	MyIo fin1     = new MyIo(fname1);  // read in the problem
	noCars        = fin1.getNextInt();
	noOpt         = fin1.getNextInt();
	noClass       = fin1.getNextInt();
	p             = new int[noOpt];
	q             = new int[noOpt];
	demand        = new int[noClass];
	option        = new int[noClass][noOpt];
	optDemand     = new int[noOpt];
	posn          = new int[noCars];
	posnOpt       = new int[noCars][noOpt];

	for (int i=0;i<noOpt;i++) p[i] = fin1.getNextInt();
	for (int i=0;i<noOpt;i++) q[i] = fin1.getNextInt();
	for (int i=0;i<noClass;i++){
	    fin1.getNextInt();  // skip id number
	    demand[i] = fin1.getNextInt();
	    for (int j=0;j<noOpt;j++)
		option[i][j] = fin1.getNextInt();
	}
	fin1.close();
	MyIo fin2 = new MyIo(fname2);  // read in the solution
	for (int i=0;i<noCars;i++) {
	    posn[i] = fin2.getNextInt();
	    for (int j=0;j<noOpt;j++) posnOpt[i][j] = option[posn[i]][j];
	}
	fin2.close();
    }

    private boolean checkDemand(int c){
	int d = demand[c];
	for (int i=0;i<noCars;i++)
	    if (posn[i] == c) d--;
	return d == 0;
    }

    public boolean checkDemand(){
	boolean okay = true;
	for (int i=0;i<noClass && okay;i++) okay = checkDemand(i);
	return okay;
    }

    private boolean checkPQ(int j){
	boolean okay = true;
	for (int i=0;i<noCars-q[j] && okay;i++){
	    int m = 0;
	    for (int k=0;k<q[j];k++) m = m + posnOpt[i+k][j];
	    okay = m <= p[j];
	}
	return okay;
    }

    public boolean checkPQ(){
	boolean okay = true;
	for (int j=0;j<noOpt && okay;j++) okay = checkPQ(j);
	return okay;
    }

    public static void main(String[] args) throws FileNotFoundException, IOException, Exception {
	Certificate cert = new Certificate(args[0],args[1]);
	System.out.println("demand: " + cert.checkDemand() + "  p/q: " + cert.checkPQ());
    }
}
